@@ -1,7 +1,7 @@
 use v5.26;
 use Object::Pad;
 
-package Blockchain::Ethereum::Keystore 0.002;
+package Blockchain::Ethereum::Keystore 0.003;
 class Blockchain::Ethereum::Keystore;
 
 1;
@@ -26,13 +26,20 @@ Generating a new address and writing it to a keyfile:
 
     my $key = Blockchain::Ethereum::Keystore::Key->new;
     # checksummed address
-    print $key->address->prefixed;
+    print $key->address;
     my $keyfile = Blockchain::ethereum::Keystore::Keyfile->new;
 
     $keyfile->import_key($key);
     $keyfile->write_to_file("...");
     ...
 
+Generating a new seed and derivating new keys (BIP44):
+
+    my $seed = Blockchain::Ethereum::Keystore::Seed->new;
+    my $key = $seed->derive_key(0);
+    print $key->address;
+    ...
+
 Importing a keyfile and changing the password:
 
     my $keyfile = Blockchain::Ethereum::Keystore::Keyfile->new;
