@@ -1,9 +1,25 @@
 use v5.26;
 use Object::Pad;
 
-package Blockchain::Ethereum::Keystore::Address 0.002;
+package Blockchain::Ethereum::Keystore::Address 0.003;
 class Blockchain::Ethereum::Keystore::Address;
 
+=encoding utf8
+
+=head1 NAME
+
+Blockchain::Ethereum::Keystore::Address
+
+=head1 SYNOPSIS
+
+Address utilities
+
+    my $address = Blockchain::Ethereum::Address->new(0x...);
+    print $address;
+    ...
+
+=cut
+
 use Carp;
 use Digest::Keccak qw(keccak_256_hex);
 
@@ -24,16 +40,41 @@ ADJUST {
     $self->set_address($checksummed_chars);
 }
 
-method unprefixed {
+method no_prefix {
 
     my $unprefixed = $self->address =~ s/^0x//r;
     return $unprefixed;
 }
 
-method prefixed {
+use overload
+    fallback => 1,
+    '""'     => \&to_string;
+
+method to_string {
 
     return $self->address if $self->address =~ /^0x/;
     return '0x' . $self->address;
 }
 
 1;
+
+__END__
+
+=head1 AUTHOR
+
+Reginaldo Costa, C<< <refeco at cpan.org> >>
+
+=head1 BUGS
+
+Please report any bugs or feature requests to L<https://github.com/refeco/perl-ethereum-keystore>
+
+=head1 LICENSE AND COPYRIGHT
+
+This software is Copyright (c) 2023 by REFECO.
+
+This is free software, licensed under:
+
+  The MIT License
+
+=cut
+
